@@ -17,15 +17,6 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
  ************************************************************************/
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <qstring.h>
-#include <libgen.h>
-#include <qmessagebox.h>
-#include <kfm.h>
-
-#include "stringfunc.h"
-
 #include "gui.h"
 
 #ifndef KIF_MAGIC
@@ -53,103 +44,24 @@
 
 // some pictures
 #include "kinstpic.xpm"
-#include "books.xpm"
 
-tYesNoDlg::tYesNoDlg(QWidget *parent, const char *name)
-  : QDialog(parent, name, true)
-{
-  setCaption(_i18n("kinst - Shared Libraries\n"));
-  setMinimumSize(430, 130);
-
-  text_label = new QLabel(this);
-  text_label->setText("");
-  text_label->setAlignment(AlignVCenter | AlignHCenter);
-  text_label->show();
-
-  yes_button = new QPushButton(this);
-  yes_button->setText(_i18n("Yes"));
-  yes_button->show();
-  connect(yes_button, SIGNAL(clicked()), this, SLOT(YesPressed()));
-  
-  no_button = new QPushButton(this);
-  no_button->setText(_i18n("No"));
-  no_button->show();
-  connect(no_button, SIGNAL(clicked()), this, SLOT(NoPressed()));
-
-  BooksImage = new QPixmap(books);
-
-  BooksImage_Label = new QLabel(this);
-  BooksImage_Label->setPixmap(*BooksImage);
-  BooksImage_Label->show();
-
-  i = 0;
-}
-
-void tYesNoDlg::resizeEvent(QResizeEvent*)
-{
-  yes_button->setGeometry(10,
-			  height()-35,
-			  90,
-			  30);
-
-  no_button->setGeometry(width()-100,
-			 height()-35,
-			 90,
-			 30);
-
-  text_label->setGeometry(70,
-			  5,
-			  width()-80,
-			  height()-yes_button->height()-15);
-
-  BooksImage_Label->setGeometry(10,
-				(height()-yes_button->height())/2-24-5,
-				49,
-				49);
-}
-
-void tYesNoDlg::YesPressed()
-{
-  i = 1;
-  hide();
-}
-
-void tYesNoDlg::NoPressed()
-{
-  i = 0;
-  hide();
-}
-
-int tYesNoDlg::getYesNo(QString text_to_display)
-{
-  i = 0;
-
-  text = text_to_display;
-
-  text_label->setText(text);
-
-  show();
-
-  return(i);
-}
-
-kinstMainWidget::kinstMainWidget():KTopLevelWidget()
+kinstMainWidget::kinstMainWidget():KMainWindow()
 {
   QFont AFont;
   KIFReader = new tKIFReader;
   KIFInstall = new tKIFInstall(_KIF_Source_Directory, this);
   KDEConfig = new tKDEConfig();
+  GNOMEConfig = new tGNOMEConfig();
   ScriptRun = new tScriptRun(_KIF_Source_Directory);
   SharedLibs = new tInstSharedLibraries();
-  filemanager = new KFM();
   KISS = new tKISS(_KIF_Source_Directory);
 
   // Create YesNoDlg
-  YesNoDlg = new tYesNoDlg(this, "YesNoDlg");
+  YesNoDlg = new tYesNoDlg(this, _i18n("kinst - Shared Libraries"),
+			   "YesNoDlg");
   YesNoDlg->hide();
 
   // Main window properties
-  setCaption(_i18n("kinst"));
   resize(MAIN_WINDOW_WIDTH, MAIN_WINDOW_HEIGHT);
   setMinimumSize(MAIN_WINDOW_WIDTH, MAIN_WINDOW_HEIGHT);
 
@@ -161,6 +73,7 @@ kinstMainWidget::kinstMainWidget():KTopLevelWidget()
 
   // Create SetupPictureLabel
   SetupPictureLabel = new QLabel(this);
+  SetupPictureLabel->setAlignment(AlignCenter);
   SetupPictureLabel->setPixmap(*SetupPicture);
   SetupPictureLabel->setFrameStyle(QFrame::Panel|QFrame::Sunken);
   SetupPictureLabel->setLineWidth(2);
@@ -224,7 +137,7 @@ kinstMainWidget::kinstMainWidget():KTopLevelWidget()
   connect(DestFolderButton,SIGNAL(clicked()),SLOT(DestFolderButtonPressed()));
 
   // Create DestFolderDialog
-  DestFolderDialog = new KDirDialog(getenv("HOME"),this,"DestFolderDialog");
+  DestFolderDialog = new KFileDialog(getenv("HOME"),"*",this,"",false);
   DestFolderDialog->hide();
 
   // Create MultiLineEdit
@@ -284,6 +197,10 @@ kinstMainWidget::kinstMainWidget():KTopLevelWidget()
   KMenuTreeDlg = new tKMenuTreeDlg(this, "KMenuTree");
   KMenuTreeDlg->hide();
 
+  // Create RPMDepDlg
+  RPMDepDlg = new tRPMDepDlg(this, "RPMDepDlg");
+  RPMDepDlg->hide();
+
   // Create ExitButton
   ExitButton = new QPushButton(this);
   ExitButton->setText(_i18n("Exit"));
@@ -307,6 +224,14 @@ kinstMainWidget::kinstMainWidget():KTopLevelWidget()
   AboutButton->setText(_i18n("About..."));
   connect(AboutButton,SIGNAL(clicked()),SLOT(AboutPressed()));
 
+  // Create FileProgress
+  FileProgress = new KProgress(this, "fileprogress");
+  FileProgress->hide();
+
+  // Create ProcessingFile_label
+  ProcessingFile_label = new QLabel(this);
+  ProcessingFile_label->hide();
+
   StepNr = 1;
 }
 
@@ -372,8 +297,11 @@ int kinstMainWidget::kinstMainWidgetKIFinit(char *infofilename)
     DestGroupLineEdit->setEnabled(false);
 
   if(strlen(KIFReader->KIFOptions->GraphicsFile) != 0)
-    SetupPictureLabel->setPixmap(KIFReader->KIFOptions->GraphicsFile);
-
+    {
+      QPixmap pixmap(KIFReader->KIFOptions->GraphicsFile);
+      SetupPictureLabel->setPixmap(pixmap);
+    }
+    
   realpath(infofilename, String2);
   strncpy(_KIF_Source_Directory, dirname(String2), FILENAME_MAX);
 
@@ -551,7 +479,8 @@ void kinstMainWidget::DestFolderButtonPressed()
 {
   char newdir[FILENAME_MAX];
 
-  qstrncpy(newdir, DestFolderDialog->getDirectory(getenv("HOME"), this),
+  qstrncpy(newdir, DestFolderDialog->getExistingDirectory(getenv("HOME"),
+							  this, ""),
 	   FILENAME_MAX);
   DestFolderDialog->hide();
 
@@ -571,7 +500,7 @@ void kinstMainWidget::resizeEvent(QResizeEvent*)
   TitleLabel->setGeometry(SetupPictureLabel->x()+SetupPictureLabel->width()+10,
 			  10,
 			  /* width()-273, */ /* why was this here? */
-			  width()-200, /* should go better ... */
+			  width()-150, /* should work better ... */
 			  23);
 
   r->setRect(SetupPictureLabel->x()+SetupPictureLabel->width()+10,
@@ -647,6 +576,11 @@ void kinstMainWidget::resizeEvent(QResizeEvent*)
 			   Frame->width()-40,
 			   20);
 
+  FileProgress->setGeometry(Frame->x()+20,
+			    Frame->height()-20,
+			    Frame->width()-40,
+			    20);
+
   Install1_check->setGeometry(Frame->x()+20,
 			      Frame->height()-10,
 			      (Frame->width()-40)/2-2,
@@ -704,7 +638,7 @@ void kinstMainWidget::resizeEvent(QResizeEvent*)
 
 void kinstMainWidget::OpenTheURL()
 {
-  filemanager->openURL(KIFReader->KIFOptions->URL);
+  (void) new KRun(KIFReader->KIFOptions->URL);
 }
 
 void kinstMainWidget::DestGroupButtonPressed()
@@ -735,7 +669,6 @@ int kinstMainWidget::StartInstallation()
 
   i = 1;
 
-  setEnabled(false);
   DestGroupLabel->hide();
   DestGroupLineEdit->hide();
   DestGroupButton->hide();
@@ -744,6 +677,7 @@ int kinstMainWidget::StartInstallation()
   ExitButton->setEnabled(false);
   NextButton->setEnabled(false);
   PreviousButton->setEnabled(false);
+  AboutButton->setEnabled(false);
 
   InfoLabel->setAlignment(AlignCenter);
   LabelText = _i18n("Installing ");
@@ -752,11 +686,15 @@ int kinstMainWidget::StartInstallation()
   InfoLabel->setText(LabelText);
 
   KDEConfig->KDELNKfilename = "";
+  GNOMEConfig->GNOMELNKfilename = "";
 
   ProgressBar->show();
 
   kapp->processEvents();
 
+  RPMDepDlg->setOptions(*KIFReader->KIFOptions);
+  RPMDepDlg->startCyclus(-1);
+
   qstrncpy(KIFReader->KIFOptions->DefaultMenuEntry, DestGroupLineEdit->text(),
 	   1024);
 
@@ -773,7 +711,7 @@ int kinstMainWidget::StartInstallation()
   if(inst_err == 1)
     {
       ScriptRun->setOptions(KIFReader->KIFOptions);
-      inst_err = ScriptRun->runPreScript();
+      inst_err = ScriptRun->runPreScript(-1);
     }
 
   if(inst_err == 1)
@@ -783,16 +721,19 @@ int kinstMainWidget::StartInstallation()
       LabelText += _i18n(" ...\nUnpacking Application...");
       InfoLabel->setText(LabelText);
       ProgressBar->setValue(1);
+      FileProgress->show();
       kapp->processEvents();
     }
 
   if(inst_err == 1)
     if((strcmp(KIFReader->KIFOptions->RelocatablePackage, "NO") == 0)&&
        (strcasecmp(KIFReader->KIFOptions->SourceFileType, "RPM") == 0))
-      inst_err = KIFInstall->Install(*KIFReader->KIFOptions, "");
+      inst_err = KIFInstall->Install(*KIFReader->KIFOptions, "", -1,
+				     (void*) this);
     else
     inst_err = KIFInstall->Install(*KIFReader->KIFOptions,
-				   (char *) DestFolderLineEdit->text());
+				   DestFolderLineEdit->text(), -1,
+				   (void*) this);
 
 
   if(inst_err == 1)
@@ -802,6 +743,7 @@ int kinstMainWidget::StartInstallation()
       LabelText += _i18n(" ...\nRegistering to KDE...");
       InfoLabel->setText(LabelText);
       ProgressBar->setValue(2);
+      FileProgress->hide(); FileProgress->setValue(0);
       kapp->processEvents();
     }
 
@@ -825,16 +767,25 @@ int kinstMainWidget::StartInstallation()
     errText += _i18n("\nAlready Installed!");
   }
 
-  // Go on creating the KDE stuff
+  // Go on creating the KDE and GNOME stuff
   if((inst_err == 1) && (strlen(KIFReader->KIFOptions->DefaultMenuEntry) != 0))
     {
       inst_err = 0;
       KDEConfig->setOptions(KIFReader->KIFOptions);
-      inst_err = KDEConfig->DetermineKDELNK();
+      GNOMEConfig->setOptions(KIFReader->KIFOptions);
+      inst_err = KDEConfig->DetermineKDELNK(-1);
+      if(GNOMEConfig->isGNOMEinstalled()) GNOMEConfig->DetermineGNOMELNK(-1);
       if(inst_err == 1) inst_err = KDEConfig->OpenKDELNK();
-      if(inst_err == 1) inst_err = KDEConfig->WriteKDELNK();
+      if(inst_err == 1) inst_err = KDEConfig->WriteKDELNK(-1);
       if(inst_err == 1) KDEConfig->CloseKDELNK();
 
+      if((GNOMEConfig->isGNOMEinstalled()) && (inst_err == 1))
+	{
+	  GNOMEConfig->OpenGNOMELNK();
+	  GNOMEConfig->WriteGNOMELNK(-1);
+	  GNOMEConfig->CloseGNOMELNK();
+	}
+
       // Fix the error codes
       if(inst_err != 1)
 	{
@@ -927,7 +878,7 @@ int kinstMainWidget::StartInstallation()
   if(inst_err == 1)
     {
       ScriptRun->setOptions(KIFReader->KIFOptions);
-      inst_err = ScriptRun->runDoneScript();
+      inst_err = ScriptRun->runDoneScript(-1);
     }
 
   if(inst_err == 1)
@@ -945,8 +896,8 @@ int kinstMainWidget::StartInstallation()
   if(inst_err == 1)
     {
       KISS->setOptions(KIFReader->KIFOptions);
-      nonfatal = KISS->AddToKISS((char *) DestFolderLineEdit->text(),
-				 KDEConfig->KDELNKfilename);
+      nonfatal = KISS->AddToKISS(DestFolderLineEdit->text(),
+				 KDEConfig->KDELNKfilename, -1);
     }
 
   if(nonfatal != 1)
@@ -1001,6 +952,9 @@ int kinstMainWidget::StartInstallation()
 
 	kapp->processEvents();
 
+	RPMDepDlg->setOptions(*KIFReader->KIFOptions);
+	RPMDepDlg->startCyclus(w);
+
 	qstrncpy(KIFReader->KIFOptions->DefaultMenuEntry,
 		 DestGroupLineEdit->text(), 1024);
 
@@ -1027,17 +981,19 @@ int kinstMainWidget::StartInstallation()
 	    LabelText += _i18n(" ...\nUnpacking Application...");
 	    InfoLabel->setText(LabelText);
 	    ProgressBar->setValue(1);
+	    FileProgress->show();
 	    kapp->processEvents();
 	  }
 
 	if(inst_err == 1)
 	  if((strcmp(KIFReader->KIFOptions->RelocatablePackage, "NO") == 0)&&
 	     (strcasecmp(KIFReader->KIFOptions->SourceFileType, "RPM") == 0))
-	    inst_err = KIFInstall->Install(*KIFReader->KIFOptions, "", w);
+	    inst_err = KIFInstall->Install(*KIFReader->KIFOptions, "", w,
+					   (void*) this);
 	  else
 	    inst_err =
 	      KIFInstall->Install(*KIFReader->KIFOptions,
-				  (char *) DestFolderLineEdit->text(), w);
+				  DestFolderLineEdit->text(), w, (void*) this);
 
 	if(inst_err == 1)
 	  {
@@ -1046,6 +1002,7 @@ int kinstMainWidget::StartInstallation()
 	    LabelText += _i18n(" ...\nRegistering to KDE...");
 	    InfoLabel->setText(LabelText);
 	    ProgressBar->setValue(2);
+	    FileProgress->hide(); FileProgress->setValue(0);
 	    kapp->processEvents();
 	  }
 
@@ -1075,11 +1032,21 @@ int kinstMainWidget::StartInstallation()
 	  {
 	    inst_err = 0;
 	    KDEConfig->setOptions(KIFReader->KIFOptions);
+	    GNOMEConfig->setOptions(KIFReader->KIFOptions);
 	    inst_err = KDEConfig->DetermineKDELNK(w);
+	    if(GNOMEConfig->isGNOMEinstalled())
+	      GNOMEConfig->DetermineGNOMELNK(w);
 	    if(inst_err == 1) inst_err = KDEConfig->OpenKDELNK();
 	    if(inst_err == 1) inst_err = KDEConfig->WriteKDELNK(w);
 	    if(inst_err == 1) KDEConfig->CloseKDELNK();
 
+	    if((GNOMEConfig->isGNOMEinstalled()) && (inst_err == 1))
+	      {
+		GNOMEConfig->OpenGNOMELNK();
+		GNOMEConfig->WriteGNOMELNK(w);
+		GNOMEConfig->CloseGNOMELNK();
+	      }
+
 	    // Fix the error codes
 	    if(inst_err != 1)
 	      {
@@ -1194,7 +1161,7 @@ int kinstMainWidget::StartInstallation()
 	if(inst_err == 1)
 	  {
 	    KISS->setOptions(KIFReader->KIFOptions);
-	    nonfatal = KISS->AddToKISS((char *) DestFolderLineEdit->text(),
+	    nonfatal = KISS->AddToKISS(DestFolderLineEdit->text(),
 				       KDEConfig->KDELNKfilename, w);
 	  }
 
@@ -1212,6 +1179,7 @@ int kinstMainWidget::StartInstallation()
       }
 
   KDEConfig->RestartPanel();
+  if(GNOMEConfig->isGNOMEinstalled()) GNOMEConfig->RestartPanel();
 
   if((strcasecmp(KIFReader->KIFOptions->RecommendReboot, "YES") == 0)
      && (inst_err == 1))
@@ -1220,6 +1188,38 @@ int kinstMainWidget::StartInstallation()
 			     _i18n("A system reboot is recommended before you start using the installed software."));
 
   ExitButton->setEnabled(true);
+  AboutButton->setEnabled(true);
 
   return(inst_err);
 }
+
+void kinstMainWidget::setTotalSteps(int steps)
+{
+  FileProgress->setRange(0, steps);
+  KApplication::kApplication()->processEvents();
+}
+
+void kinstMainWidget::setStatus(int percent, char* text)
+{
+  FileProgress->setValue(percent);
+  ProcessingFile_label->setText(text);
+  KApplication::kApplication()->processEvents();
+}
+
+void setTotalSteps(int steps, void* parent)
+{
+  kinstMainWidget* p;
+
+  p = (kinstMainWidget*) parent;
+
+  p->setTotalSteps(steps);
+}
+
+void setStatus(int percent, char* text, void* parent)
+{
+  kinstMainWidget* p;
+
+  p = (kinstMainWidget*) parent;
+
+  p->setStatus(percent, text);
+}
