@@ -17,13 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
  ************************************************************************/
 
-#include "tparams.h"
-#include "locale.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <qstring.h>
+#include "createinst.h"
 
 #ifndef KIF_MAGIC
 #define KIF_MAGIC "[KDE Install Information]"
@@ -43,6 +37,8 @@ int CreateInstallation(tParams* params)
 
   char cptractpackage[2];
 
+  char cptrversion[4];
+
   FILE* f;
 
   int i;
@@ -248,6 +244,27 @@ int CreateInstallation(tParams* params)
   fputs(String, f);
   fputc(EOL, f);
 
+  String = "VERSIONMAJ";
+  String += "=";
+  sprintf(cptrversion, "%i", params->KIFOptions.VersionMaj);
+  String += cptrversion;
+  fputs(String, f);
+  fputc(EOL, f);
+
+  String = "VERSIONMIN";
+  String += "=";
+  sprintf(cptrversion, "%i", params->KIFOptions.VersionMin);
+  String += cptrversion;
+  fputs(String, f);
+  fputc(EOL, f);
+
+  String = "VERSIONREL";
+  String += "=";
+  sprintf(cptrversion, "%i", params->KIFOptions.VersionRel);
+  String += cptrversion;
+  fputs(String, f);
+  fputc(EOL, f);
+
   for(actpackage = 0;actpackage < MAX_ADDITIONAL_PACKAGES;actpackage++)
     {
       if(strlen(params->KIFOptions.ProgramName2[actpackage]) > 0)
@@ -355,6 +372,33 @@ int CreateInstallation(tParams* params)
 	  String += params->KIFOptions.LibraryDir2[actpackage];
 	  fputs(String, f);
 	  fputc(EOL, f);
+
+	  String = "VERSIONMAJ";
+	  String += cptractpackage;
+	  String += "=";
+	  sprintf(cptrversion, "%i",
+		  params->KIFOptions.VersionMaj2[actpackage]);
+	  String += cptrversion;
+	  fputs(String, f);
+	  fputc(EOL, f);
+
+	  String = "VERSIONMIN";
+	  String += cptractpackage;
+	  String += "=";
+	  sprintf(cptrversion, "%i",
+		  params->KIFOptions.VersionMin2[actpackage]);
+	  String += cptrversion;
+	  fputs(String, f);
+	  fputc(EOL, f);
+
+	  String = "VERSIONREL";
+	  String += cptractpackage;
+	  String += "=";
+	  sprintf(cptrversion, "%i",
+		  params->KIFOptions.VersionRel2[actpackage]);
+	  String += cptrversion;
+	  fputs(String, f);
+	  fputc(EOL, f);
 	}
     }
 
