@@ -1,5 +1,5 @@
 /************************************************************************
- * kcreateinst - part of kinst package - gui.h                          *
+ * kcreateinst - part of kinst package - gui.cpp                        *
  * Copyright (C) 2000  Steffen Sobiech                                  *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -17,25 +17,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
  ************************************************************************/
 
-#include <stdio.h>
-#include <qfont.h>
-#include <qmessagebox.h>
-#include <qtooltip.h>
-
-#include "locale.h"
-#include "tparams.h"
-#include "preferences.h"
-#include "createdlg.h"
-#include "previnstdlg.h"
-#include "createinst.h"
-#include "tgzcompose.h"
+#include "gui.h"
 
 #ifndef MAIN_WINDOW_WIDTH
-#define MAIN_WINDOW_WIDTH 635
+#define MAIN_WINDOW_WIDTH 640
 #endif
 
 #ifndef MAIN_WINDOW_HEIGHT
-#define MAIN_WINDOW_HEIGHT 550
+#define MAIN_WINDOW_HEIGHT 475
 #endif
 
 #ifndef OPEN_TEXT_CMD
@@ -61,6 +50,7 @@ tYesNoDlg::tYesNoDlg(QWidget *parent, const char *name)
   : QDialog(parent, name, true)
 {
   setMinimumSize(320, 100);
+  resize(320, 100);
 
   text_label = new QLabel(this);
   text_label->setText("");
@@ -123,17 +113,15 @@ int tYesNoDlg::getYesNo(QString text_to_display)
   return(i);
 }
 
-kcreateinstMainWidget::kcreateinstMainWidget():KTMainWindow()
+kcreateinstMainWidget::kcreateinstMainWidget():KMainWindow()
 {
   QString string;
   QFont font;
 
   // General Window Properties
-  setCaption(_i18n("kcreateinst"));
-  MainWindowCaption = _i18n("kcreateinst");
+  setCaption("");
+  MainWindowCaption = "";
   resize(MAIN_WINDOW_WIDTH, MAIN_WINDOW_HEIGHT);
-  setMinimumWidth(MAIN_WINDOW_WIDTH);
-  setMinimumHeight(MAIN_WINDOW_HEIGHT);
 
   // Create params
   params = new tParams;
@@ -144,7 +132,7 @@ kcreateinstMainWidget::kcreateinstMainWidget():KTMainWindow()
   strcpy(params->KIFOptions.CheckPriorRPM, "");
 
   // Create config
-  config = kapp->getConfig();
+  config = KGlobal::config();
   config->setGroup("Locations");
   params->kipackpath = config->readEntry("kipackpath", "");
   params->selfextractpath = config->readEntry("selfextractpath", "");
@@ -161,7 +149,7 @@ kcreateinstMainWidget::kcreateinstMainWidget():KTMainWindow()
 
   // Create File Selection Dialog
   FileSelector = new KFileDialog(getenv("HOME"), "*", this, "FileSelector",
-				 false, false);
+				 false);
   FileSelector->hide();
 
   // Create Preferences Dialog
@@ -176,7 +164,7 @@ kcreateinstMainWidget::kcreateinstMainWidget():KTMainWindow()
   previnst_dlg = new kcreateinstPrevInstDlg(this, "previnst");
   previnst_dlg->hide();
 
-  // Create After Installation Script Builder
+  // Create Post Installation Script Builder
   scriptbuild_dlg = new kcreateinstScriptBuild(this, "scriptbuild");
   scriptbuild_dlg->hide();
 
@@ -185,56 +173,52 @@ kcreateinstMainWidget::kcreateinstMainWidget():KTMainWindow()
   NewProject_YesNoDlg->hide();
 
   // Create StatusBar
-  statusbar = new KStatusBar(this);
-  statusbar->insertItem(_i18n("Ready."), 1);
-  setStatusBar(statusbar);
-  statusbar->show();
+  statusBar()->insertItem(_i18n("Ready."), 0, 1);
+  statusBar()->setItemAlignment(0, AlignLeft|AlignVCenter);
+  statusBar()->show();
 
   // Create FileMenu
   filemenu = new QPopupMenu();
-  filemenu->insertItem(*new_picture, _i18n("&New"));
+  filemenu->insertItem(SmallIcon("filenew"), _i18n("&New"), this,
+		       SLOT(NewProject()));
   filemenu->setItemEnabled(0, true);
-  filemenu->connectItem(0, this, SLOT(NewProject()));
-  filemenu->insertItem(*open_picture, _i18n("&Open..."));
+  filemenu->insertItem(SmallIcon("fileopen"), _i18n("&Open..."), this,
+		       SLOT(LoadPressed()));
   filemenu->setItemEnabled(1, true);
-  filemenu->connectItem(1, this, SLOT(LoadPressed()));
   filemenu->insertSeparator();
-  filemenu->insertItem(*save_picture, _i18n("&Save"));
+  filemenu->insertItem(SmallIcon("filesave"), _i18n("&Save"), this,
+		       SLOT(SavePressed()));
   filemenu->setItemEnabled(3, true);
-  filemenu->connectItem(3, this, SLOT(SavePressed()));
-  filemenu->insertItem(_i18n("Save &As..."));
+  filemenu->insertItem(_i18n("Save &As..."), this, SLOT(SaveAsPressed()));
   filemenu->setItemEnabled(4, true);
-  filemenu->connectItem(4, this, SLOT(SaveAsPressed()));
   filemenu->insertSeparator();
-  filemenu->insertItem(_i18n("&Quit"));
-  filemenu->connectItem(6, kapp, SLOT(quit()));
+  filemenu->insertItem(SmallIcon("exit"), _i18n("&Quit"), kapp, SLOT(quit()));
 
   // Create OptionsMenu
   optionsmenu = new QPopupMenu();
-  optionsmenu->insertItem(_i18n("&Preferences..."));
-  optionsmenu->connectItem(0, this, SLOT(PreferencesDlgOpened()));
+  optionsmenu->insertItem(_i18n("&Preferences..."), this,
+			  SLOT(PreferencesDlgOpened()));
 
   // Create ScriptMenu
   scriptmenu = new QPopupMenu();
   scriptmenu->insertItem(_i18n("&Pre Installation Script..."));
   scriptmenu->setItemEnabled(0, false);
-  scriptmenu->insertItem(_i18n("&After Installation Script..."));
+  scriptmenu->insertItem(_i18n("&After Installation Script..."), this,
+			 SLOT(scriptbuildshow()));
   scriptmenu->setItemEnabled(1, true);
-  scriptmenu->connectItem(1, this, SLOT(scriptbuildshow()));
 
   // Create MultiPackageMenu
   multipackagemenu = new QPopupMenu();
-  multipackagemenu->insertItem(_i18n("&Additional Packages..."));
+  multipackagemenu->insertItem(_i18n("&Additional Packages..."), this,
+			       SLOT(multipackageshow()));
   multipackagemenu->setItemEnabled(0, true);
-  multipackagemenu->connectItem(0, this, SLOT(multipackageshow()));
 
   // Create MenuBar
-  menubar = new KMenuBar(this);
-  menubar->insertItem(_i18n("&File"), filemenu);
-  menubar->insertItem(_i18n("&Options"), optionsmenu);
-  menubar->insertItem(_i18n("&Scripts"), scriptmenu);
-  menubar->insertItem(_i18n("&MultiPackage"), multipackagemenu);
-  menubar->insertSeparator();
+  menuBar()->insertItem(_i18n("&File"), filemenu);
+  menuBar()->insertItem(_i18n("&Options"), optionsmenu);
+  menuBar()->insertItem(_i18n("&Scripts"), scriptmenu);
+  menuBar()->insertItem(_i18n("&MultiPackage"), multipackagemenu);
+  menuBar()->insertSeparator();
   string = "kcreateinst (";
   string += PACKAGE;
   string += ") - ";
@@ -242,34 +226,32 @@ kcreateinstMainWidget::kcreateinstMainWidget():KTMainWindow()
   string += _i18n("\n\nCopyright (C) 2000  Steffen Sobiech\n\n");
   string += _i18n("This program underlies the GPL and comes with\n");
   string += _i18n("ABSOLUTELY NO WARRANTY.\n");
-  menubar->insertItem(_i18n("&Help"), kapp->getHelpMenu(false, string));
-  setMenu(menubar);
-  menubar->show();
-  connect(menubar, SIGNAL(moved(menuPosition)), this, SLOT(surr_moved()));
+  menuBar()->insertItem(_i18n("&Help"), helpMenu(string, false));
+  menuBar()->show();
 
   // Create ToolBar
-  toolbar = new KToolBar(this);
-  toolbar->insertButton(*new_picture, 1, true, _i18n("New"));
-  toolbar->addConnection(1, SIGNAL(clicked()), this, SLOT(NewProject()));
-  toolbar->insertButton(*open_picture, 2, true, _i18n("Open"));
-  toolbar->addConnection(2, SIGNAL(clicked()), this, SLOT(LoadPressed()));
-  toolbar->insertButton(*save_picture, 3, true, _i18n("Save"));
-  toolbar->addConnection(3, SIGNAL(clicked()), this, SLOT(SavePressed()));
-  toolbar->insertButton(*start_picture, 4, true, _i18n("Start Creation"));
-  toolbar->addConnection(4, SIGNAL(clicked()), this, SLOT(CreatePressed()));
-  toolbar->insertButton(*exit_picture, 5, true, _i18n("Exit"));
-  toolbar->addConnection(5, SIGNAL(clicked()), kapp, SLOT(quit()));
-  addToolBar(toolbar);
-  toolbar->show();
-  connect(toolbar, SIGNAL(moved(BarPosition)), this, SLOT(surr_moved()));
+  toolBar(0)->insertButton(MainBarIcon("filenew"), 1, true, _i18n("New"));
+  toolBar(0)->addConnection(1, SIGNAL(clicked()), this, SLOT(NewProject()));
+  toolBar(0)->insertButton(MainBarIcon("fileopen"), 2, true, _i18n("Open"));
+  toolBar(0)->addConnection(2, SIGNAL(clicked()), this, SLOT(LoadPressed()));
+  toolBar(0)->insertButton(MainBarIcon("filesave"), 3, true, _i18n("Save"));
+  toolBar(0)->addConnection(3, SIGNAL(clicked()), this, SLOT(SavePressed()));
+  toolBar(0)->insertButton(*start_picture, 4, true, _i18n("Start Creation"));
+  toolBar(0)->addConnection(4, SIGNAL(clicked()), this, SLOT(CreatePressed()));
+  toolBar(0)->insertButton(MainBarIcon("exit"), 5, true, _i18n("Exit"));
+  toolBar(0)->addConnection(5, SIGNAL(clicked()), kapp, SLOT(quit()));
+  toolBar(0)->show();
 
   // Create MainView
   mainview = new QWidget(this);
-  setView(mainview);
+  mainview->setMinimumWidth(MAIN_WINDOW_WIDTH);
+  mainview->setMinimumHeight(MAIN_WINDOW_HEIGHT);
+  setCentralWidget(mainview);
 
   // Create kinst_picture and label
   kinst_picture = new QPixmap(kcreateinst_xpm);
   kinst_picture_label = new QLabel(mainview);
+  kinst_picture_label->setAlignment(AlignCenter);
   kinst_picture_label->setPixmap(*kinst_picture);
   kinst_picture_label->setFrameStyle(QFrame::Panel|QFrame::Sunken);
   kinst_picture_label->setLineWidth(2);
@@ -593,7 +575,7 @@ kcreateinstMainWidget::kcreateinstMainWidget():KTMainWindow()
   name_edit->setText("");
   name_edit->show();
 
-  // Create Name_Label
+  // Create name_label
   name_label = new QLabel(mainview);
   name_label->setText(_i18n("Program Name"));
   font.setBold(true);
@@ -602,7 +584,42 @@ kcreateinstMainWidget::kcreateinstMainWidget():KTMainWindow()
   name_label->setAlignment(AlignCenter);
   name_label->show();
 
+  // Create version_label
+  version_label = new QLabel(mainview);
+  version_label->setText(_i18n("Version"));
+  font.setBold(true);
+  font.setPointSize(15);
+  version_label->setFont(font);
+  version_label->setAlignment(AlignCenter);
+  version_label->show();
+
+  // Version input range validator
+  versionval = new QIntValidator(this);
+  versionval->setRange(0, 127);
+
+  // Create versionmaj_edit
+  versionmaj_edit = new QLineEdit(mainview);
+  versionmaj_edit->setText("");
+  versionmaj_edit->setValidator(versionval);
+  versionmaj_edit->setMaxLength(3);
+  versionmaj_edit->show();
+
+  // Create versionmin_edit
+  versionmin_edit = new QLineEdit(mainview);
+  versionmin_edit->setText("");
+  versionmin_edit->setValidator(versionval);
+  versionmin_edit->setMaxLength(3);
+  versionmin_edit->show();
+
+  // Create versionrel_edit
+  versionrel_edit = new QLineEdit(mainview);
+  versionrel_edit->setText("");
+  versionrel_edit->setValidator(versionval);
+  versionrel_edit->setMaxLength(3);
+  versionrel_edit->show();
+
   // Create KDNDDropZones
+  /*
   sourcefile_dnd = new KDNDDropZone(sourcefile_edit, DndText);
   connect(sourcefile_dnd, SIGNAL(dropAction(KDNDDropZone*)),
 	  SLOT(sourcefile_dnd_drop()));
@@ -620,6 +637,7 @@ kcreateinstMainWidget::kcreateinstMainWidget():KTMainWindow()
 	  SLOT(defaultinstallpath_dnd_drop()));
   url_dnd = new KDNDDropZone(url_edit, DndURL);
   connect(url_dnd, SIGNAL(dropAction(KDNDDropZone*)), SLOT(url_dnd_drop()));
+  */
 
   // Create TGZViewDlg
   TGZViewDlg = new tTGZViewDlg(this, "TGZViewDlg");
@@ -629,14 +647,19 @@ kcreateinstMainWidget::kcreateinstMainWidget():KTMainWindow()
   MultiPackDlg = new tMultiPackDlg(this, "MultiPackDlg");
   MultiPackDlg->hide();
 
+  // Create RPMDepDlg
+  RPMDepDlg = new kcreateinstRPMDepDlg(this, "RPMDepDlg");
+  RPMDepDlg->hide();
+
   // Init ActProject
   ActProject = "";
 }
 
 void kcreateinstMainWidget::resizeEvent(QResizeEvent*)
 {
-  updateRects();
-
+  // Resize statusbar
+  statusBar()->setGeometry(statusBar()->x(), statusBar()->y(),
+			   width(), statusBar()->height());
   // Resize separation
   Separation->setGeometry((mainview->width()/2)-45,
 			  10,
@@ -645,9 +668,9 @@ void kcreateinstMainWidget::resizeEvent(QResizeEvent*)
 
   // Resize kinst_picture and label
   kinst_picture_label->setGeometry(mainview->width()-88,
-				   35,
+				   10,
 				   84,
-				   304);
+				   262);
 
   // Resize separation2
   Separation2->setGeometry(5,
@@ -895,7 +918,7 @@ void kcreateinstMainWidget::resizeEvent(QResizeEvent*)
   // Resize sourcefiletype_group and members
   sourcefiletype_group->setGeometry(5,
   				    Separation2->y()+50,
-				    Separation->x()-10,
+				    Separation->x()-110,
 				    45);
   
   tgz_radio->setGeometry(sourcefiletype_group->x()+5,
@@ -952,9 +975,11 @@ void kcreateinstMainWidget::resizeEvent(QResizeEvent*)
   previnstdetector_button->setGeometry(sourcefiletype_group->x()+
 				       sourcefiletype_group->width()+5,
 				       Separation2->y()+59,
-				       mainview->width()-
+				       /*(mainview->width()-
 				       sourcefiletype_group->width()-
-				       kinst_picture_label->width()-19,
+				       kinst_picture_label->width()-19)/2,*/
+				       previnstdetector_button->
+				       sizeHint().width(),
 				       35);
 
   // Resize exec_button
@@ -992,8 +1017,7 @@ void kcreateinstMainWidget::resizeEvent(QResizeEvent*)
   // Resize separation3
   Separation3->setGeometry(Separation->x()+5,
 			   librarydir_edit->y()+librarydir_edit->height()+5,
-			   mainview->width()-kinst_picture_label->width()-
-			   Separation->x()-13,
+			   mainview->width()-Separation->x()-10,
 			   3);
 
   // Resize name_label
@@ -1008,11 +1032,31 @@ void kcreateinstMainWidget::resizeEvent(QResizeEvent*)
 			 mainview->width()-
 			 Separation->x()-kinst_picture_label->width()-78,
 			 20);
-}
 
-void kcreateinstMainWidget::surr_moved()
-{
-  resizeEvent(NULL);
+  // Resize version_label
+  version_label->setGeometry(name_edit->x()+name_edit->width()+5,
+			     name_label->y(),
+			     mainview->width()-
+			     Separation->x()-name_edit->width()-45,
+			     20);
+
+  // Resize versionmaj_edit
+  versionmaj_edit->setGeometry(version_label->x(),
+			       name_edit->y(),
+			       (version_label->width()-10)/3,
+			       20);
+
+  // Resize versionmin_edit
+  versionmin_edit->setGeometry(versionmaj_edit->x()+versionmaj_edit->width()+5,
+			       name_edit->y(),
+			       (version_label->width()-10)/3,
+			       20);
+
+  // Resize versionrel_edit
+  versionrel_edit->setGeometry(versionmin_edit->x()+versionmin_edit->width()+5,
+			       name_edit->y(),
+			       (version_label->width()-10)/3,
+			       20);
 }
 
 void kcreateinstMainWidget::PreferencesDlgOpened()
@@ -1033,7 +1077,7 @@ void kcreateinstMainWidget::CreatePressed()
   create_dlg->getCreatePrefs(params, &startit);
   if(startit)
     {
-      statusbar->changeItem(_i18n("Creating Package..."), 1);
+      statusBar()->changeItem(_i18n("Creating Package..."), 0);
       kapp->processEvents();
 
       qstrcpy(params->KIFOptions.ProgramName, name_edit->text());
@@ -1126,7 +1170,7 @@ void kcreateinstMainWidget::CreatePressed()
 				      _i18n("Unknown general error"));
 	}
 
-      statusbar->changeItem(_i18n("Ready."), 1);
+      statusBar()->changeItem(_i18n("Ready."), 0);
     }
 }
 
@@ -1135,7 +1179,7 @@ void kcreateinstMainWidget::Browse1Pressed()
   QString String;
   String = FileSelector->getOpenFileName(getenv("HOME"),
 					 "*", mainview,
-					 "Browse1");
+					 _i18n("Choose a file"));
   if(qstrlen(String) > 0)
     {
       qstrncpy(params->KIFOptions.SourceFile, String, 1024);
@@ -1150,7 +1194,7 @@ void kcreateinstMainWidget::Browse2Pressed()
   QString String;
   String = FileSelector->getOpenFileName(getenv("HOME"),
 					 "*", mainview,
-					 "Browse2");
+					 _i18n("Choose a file"));
   if(qstrlen(String) > 0)
     {
       qstrncpy(params->KIFOptions.ReadMeFile, String, 1024);
@@ -1165,7 +1209,7 @@ void kcreateinstMainWidget::Browse3Pressed()
   QString String;
   String = FileSelector->getOpenFileName(getenv("HOME"),
 					 "*", mainview,
-					 "Browse3");
+					 _i18n("Choose a file"));
   if(qstrlen(String) > 0)
     {
       qstrncpy(params->KIFOptions.GraphicsFile, String, 1024);
@@ -1180,7 +1224,7 @@ void kcreateinstMainWidget::Browse4Pressed()
   QString String;
   String = FileSelector->getOpenFileName(getenv("HOME"),
 					 "*", mainview,
-					 "Browse4");
+					 _i18n("Choose a file"));
   if(qstrlen(String) > 0)
     {
       qstrncpy(params->KIFOptions.PreInstallScript, String, 1024);
@@ -1263,13 +1307,14 @@ void kcreateinstMainWidget::Browse9Pressed()
 void kcreateinstMainWidget::LoadPressed()
 {
   QString String;
+  char cptr_version[4];
   int i;
 
   i = 0;
 
   String = FileSelector->getOpenFileName(getenv("HOME"),
 					 "*", mainview,
-					 "LoadPressed");
+					 _i18n("Load project file"));
 
   if(qstrlen(String) > 0) i = LoadParams(params, String);
   else return;
@@ -1286,6 +1331,10 @@ void kcreateinstMainWidget::LoadPressed()
     case 3: QMessageBox::information(this, _i18n("kcreateinst - Load Project"),
 				     _i18n("I/O error while reading file"));
     break;
+    case 4: QMessageBox::information(this, _i18n("kcreateinst - Load Project"),
+				     _i18n("Wrong project file version"));
+    break;
+    break;
     default: QMessageBox::warning(this, _i18n("kcreateinst - Load Project"),
 				  _i18n("Unknown general error"));
     }
@@ -1293,9 +1342,7 @@ void kcreateinstMainWidget::LoadPressed()
   if(i != 1) return;
 
   ActProject = String;
-  MainWindowCaption = _i18n("kcreateinst");
-  MainWindowCaption += ": ";
-  MainWindowCaption += ActProject;
+  MainWindowCaption = ActProject;
   setCaption(MainWindowCaption);
 
   name_edit->setText(params->KIFOptions.ProgramName);
@@ -1337,6 +1384,12 @@ void kcreateinstMainWidget::LoadPressed()
   defaultmenuentry_edit->setText(params->KIFOptions.DefaultMenuEntry);
   preinstallscript_edit->setText(params->KIFOptions.PreInstallScript);
   doneinstallscript_edit->setText(params->KIFOptions.DoneInstallScript);
+  sprintf(cptr_version, "%i", params->KIFOptions.VersionMaj);
+  versionmaj_edit->setText(cptr_version);
+  sprintf(cptr_version, "%i", params->KIFOptions.VersionMin);
+  versionmin_edit->setText(cptr_version);
+  sprintf(cptr_version, "%i", params->KIFOptions.VersionRel);
+  versionrel_edit->setText(cptr_version);
 
   FileSelector->hide();
 }
@@ -1350,7 +1403,7 @@ void kcreateinstMainWidget::SaveAsPressed()
 
   String = FileSelector->getSaveFileName(getenv("HOME"),
 					 "*", mainview,
-					 "SavePressed");
+					 _i18n("Save project file"));
 
   qstrcpy(params->KIFOptions.ProgramName, name_edit->text());
   if(tgz_radio->isChecked())
@@ -1395,6 +1448,9 @@ void kcreateinstMainWidget::SaveAsPressed()
 	  preinstallscript_edit->text());
   qstrcpy(params->KIFOptions.DoneInstallScript,
 	  doneinstallscript_edit->text());
+  params->KIFOptions.VersionMaj = atoi(versionmaj_edit->text());
+  params->KIFOptions.VersionMin = atoi(versionmin_edit->text());
+  params->KIFOptions.VersionRel = atoi(versionrel_edit->text());
 
   if(qstrlen(String) > 0) i = SaveParams(params, String);
   else return;
@@ -1416,9 +1472,7 @@ void kcreateinstMainWidget::SaveAsPressed()
     }
 
   ActProject = String;
-  MainWindowCaption = _i18n("kcreateinst");
-  MainWindowCaption += ": ";
-  MainWindowCaption += ActProject;
+  MainWindowCaption = ActProject;
   setCaption(MainWindowCaption);
 
   FileSelector->hide();
@@ -1479,6 +1533,9 @@ void kcreateinstMainWidget::SavePressed()
 	  preinstallscript_edit->text());
   qstrcpy(params->KIFOptions.DoneInstallScript,
 	  doneinstallscript_edit->text());
+  params->KIFOptions.VersionMaj = atoi(versionmaj_edit->text());
+  params->KIFOptions.VersionMin = atoi(versionmin_edit->text());
+  params->KIFOptions.VersionRel = atoi(versionrel_edit->text());
 
   if(qstrlen(ActProject) > 0) i = SaveParams(params, ActProject);
   else return;
@@ -1527,6 +1584,9 @@ void kcreateinstMainWidget::NewProject()
   doneinstallscript_edit->setText("");
   librarydir_edit->setText("");
   url_edit->setText("");
+  versionmaj_edit->setText("");
+  versionmin_edit->setText("");
+  versionrel_edit->setText("");
   strcpy(params->KIFOptions.CheckPriorFile, "");
   strcpy(params->KIFOptions.CheckPriorRPM, "");
 
@@ -1542,10 +1602,13 @@ void kcreateinstMainWidget::NewProject()
       strcpy(params->KIFOptions.PreInstallScript2[i], "");
       strcpy(params->KIFOptions.DoneInstallScript2[i], "");
       strcpy(params->KIFOptions.LibraryDir2[i], "");
+      params->KIFOptions.VersionMaj2[i] = 0;
+      params->KIFOptions.VersionMin2[i] = 0;
+      params->KIFOptions.VersionRel2[i] = 0;
     }
 
   ActProject = "";
-  MainWindowCaption = _i18n("kcreateinst");
+  MainWindowCaption = "";
   setCaption(MainWindowCaption);
 }
 
@@ -1557,6 +1620,7 @@ void kcreateinstMainWidget::tgz_radio_pressed()
       doneinstallscript_button->setEnabled(true);
       icon_button->setEnabled(true);
       kdelnkadd_button->setEnabled(true);
+      librarydir_button->setEnabled(true);
     }
 }
 
@@ -1568,6 +1632,7 @@ void kcreateinstMainWidget::rpm_radio_pressed()
       doneinstallscript_button->setEnabled(false);
       icon_button->setEnabled(false);
       kdelnkadd_button->setEnabled(false);
+      librarydir_button->setEnabled(false);
     }
 }
 
@@ -1579,6 +1644,7 @@ void kcreateinstMainWidget::deb_radio_pressed()
       doneinstallscript_button->setEnabled(false);
       icon_button->setEnabled(false);
       kdelnkadd_button->setEnabled(false);
+      librarydir_button->setEnabled(false);
     }
 }
 
@@ -1600,7 +1666,7 @@ void kcreateinstMainWidget::sourcefile_dnd_drop()
   QString FillData;
   long int i;
 
-  DNDData = sourcefile_dnd->getData();
+  // DNDData = sourcefile_dnd->getData();
   FillData = "";
 
   if((DNDData[0] == 'f') && (DNDData[1] == 'i') && (DNDData[2] == 'l') &&
@@ -1623,7 +1689,7 @@ void kcreateinstMainWidget::readmefile_dnd_drop()
   QString FillData;
   long int i;
 
-  DNDData = readmefile_dnd->getData();
+  // DNDData = readmefile_dnd->getData();
   FillData = "";
 
   if((DNDData[0] == 'f') && (DNDData[1] == 'i') && (DNDData[2] == 'l') &&
@@ -1646,7 +1712,7 @@ void kcreateinstMainWidget::graphicsfile_dnd_drop()
   QString FillData;
   long int i;
 
-  DNDData = graphicsfile_dnd->getData();
+  // DNDData = graphicsfile_dnd->getData();
   FillData = "";
 
   if((DNDData[0] == 'f') && (DNDData[1] == 'i') && (DNDData[2] == 'l') &&
@@ -1669,7 +1735,7 @@ void kcreateinstMainWidget::preinstallscript_dnd_drop()
   QString FillData;
   long int i;
 
-  DNDData = preinstallscript_dnd->getData();
+  // DNDData = preinstallscript_dnd->getData();
   FillData = "";
 
   if((DNDData[0] == 'f') && (DNDData[1] == 'i') && (DNDData[2] == 'l') &&
@@ -1692,7 +1758,7 @@ void kcreateinstMainWidget::defaultinstallpath_dnd_drop()
   QString FillData;
   long int i;
 
-  DNDData = defaultinstallpath_dnd->getData();
+  // DNDData = defaultinstallpath_dnd->getData();
   FillData = "";
 
   if((DNDData[0] == 'f') && (DNDData[1] == 'i') && (DNDData[2] == 'l') &&
@@ -1711,7 +1777,7 @@ void kcreateinstMainWidget::defaultinstallpath_dnd_drop()
 
 void kcreateinstMainWidget::url_dnd_drop()
 {
-  url_edit->setText(url_dnd->getData());
+  // url_edit->setText(url_dnd->getData());
 }
 
 void kcreateinstMainWidget::sourcefile_create_button_pressed()
