@@ -20,10 +20,9 @@
 #ifndef _LOCALE_H
 #define _LOCALE_H
 
-#include <kapp.h>
 #include <klocale.h>
 
-#define _i18n(TEXT) klocale->translate(TEXT)
+#define _i18n(TEXT) i18n(TEXT)
 
 #endif
 
