@@ -18,19 +18,6 @@
  ************************************************************************/
 
 #include "multipack.h"
-#include "tparams.h"
-#include "locale.h"
-#include "stringfunc.h"
-#include "tgzcompose.h"
-
-#include <sys/stat.h>
-#include <sys/types.h>
-#include <fcntl.h>
-#include <unistd.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <qdialog.h>
-#include <qmessagebox.h>
 
 #ifndef MIN_WIDTH
 #define MIN_WIDTH 520
@@ -143,6 +130,13 @@ tMultiPackDlg::tMultiPackDlg(QWidget *parent, const char *name)
   librarydir_label->setText(_i18n("Shared Libraries Dir"));
   librarydir_label->show();
 
+  // Create version_label
+  version_label = new QLabel(this);
+  version_label->setText(_i18n("Version"));
+  version_label->setFont(font);
+  version_label->setAlignment(AlignCenter);
+  version_label->show();
+
   // Create programname_edit
   programname_edit = new QLineEdit(this);
   programname_edit->clear();
@@ -193,6 +187,31 @@ tMultiPackDlg::tMultiPackDlg(QWidget *parent, const char *name)
   librarydir_edit->clear();
   librarydir_edit->show();
 
+  // Create input validator
+  versionval = new QIntValidator(this);
+  versionval->setRange(0, 127);
+
+  // Create versionmaj_edit
+  versionmaj_edit = new QLineEdit(this);
+  versionmaj_edit->clear();
+  versionmaj_edit->setValidator(versionval);
+  versionmaj_edit->setMaxLength(3);
+  versionmaj_edit->show();
+
+  // Create versionmin_edit
+  versionmin_edit = new QLineEdit(this);
+  versionmin_edit->clear();
+  versionmin_edit->setValidator(versionval);
+  versionmin_edit->setMaxLength(3);
+  versionmin_edit->show();
+
+  // Create versionrel_edit
+  versionrel_edit = new QLineEdit(this);
+  versionrel_edit->clear();
+  versionrel_edit->setValidator(versionval);
+  versionrel_edit->setMaxLength(3);
+  versionrel_edit->show();
+
   // Create sourcefilename_button
   sourcefilename_button = new QPushButton(this);
   sourcefilename_button->setText(_i18n("Browse"));
@@ -287,7 +306,7 @@ tMultiPackDlg::tMultiPackDlg(QWidget *parent, const char *name)
 
   // Create File Selection Dialog
   FileSelector = new KFileDialog(getenv("HOME"), "*", this, "FileSelector",
-				 false, false);
+				 false);
   FileSelector->hide();
 
   // Create TGZViewer Dialog
@@ -341,16 +360,42 @@ void tMultiPackDlg::resizeEvent(QResizeEvent*)
   programname_label->setGeometry(actpackage_frame->x()+
 				 actpackage_frame->width()+10,
 				 actpackage_frame->y()+5,
-				 width()-actpackage_frame->width()-30,
+				 width()-actpackage_frame->width()-150,
 				 20);
 
   // Resize programname_edit
   programname_edit->setGeometry(programname_label->x(),
 				programname_label->y()+
 				programname_label->height()+15,
-				width()-actpackage_frame->width()-30,
+				width()-actpackage_frame->width()-150,
 				20);
 
+  // Resize version_label
+  version_label->setGeometry(programname_label->x()+
+			     programname_label->width()+5,
+			     programname_label->y(),
+			     width()-actpackage_frame->width()-
+			     programname_label->width()-30,
+			     20);
+
+  // Resize versionmaj_edit
+  versionmaj_edit->setGeometry(version_label->x(),
+			       programname_edit->y(),
+			       (version_label->width()-15)/3,
+			       20);
+
+  // Resize versionmin_edit
+  versionmin_edit->setGeometry(versionmaj_edit->x()+versionmaj_edit->width()+5,
+			       programname_edit->y(),
+			       (version_label->width()-15)/3,
+			       20);
+
+  // Resize versionrel_edit
+  versionrel_edit->setGeometry(versionmin_edit->x()+versionmin_edit->width()+5,
+			       programname_edit->y(),
+			       (version_label->width()-15)/3,
+			       20);
+
   // Resize out_label
   out_label->setGeometry(10,
 			 10,
@@ -573,7 +618,7 @@ void tMultiPackDlg::Browse1Pressed()
   QString String;
   String = FileSelector->getOpenFileName(getenv("HOME"),
 					 "*", this,
-					 "Browse1");
+					 _i18n("Choose a file"));
   if(qstrlen(String) > 0)
     {
       qstrncpy(params->KIFOptions.SourceFile2[actpackage], String, 1024);
@@ -588,7 +633,7 @@ void tMultiPackDlg::Browse2Pressed()
   QString String;
   String = FileSelector->getOpenFileName(getenv("HOME"),
 					 "*", this,
-					 "Browse2");
+					 _i18n("Choose a file"));
   if(qstrlen(String) > 0)
     {
       qstrncpy(params->KIFOptions.PreInstallScript2[actpackage], String, 1024);
@@ -690,6 +735,8 @@ void tMultiPackDlg::compose_pressed()
 
 void tMultiPackDlg::next_pressed()
 {
+  char cptr_version[4];
+
   strncpy(params->KIFOptions.ProgramName2[actpackage],
 	  programname_edit->text(), 1024);
   strncpy(params->KIFOptions.CheckPriorFile2[actpackage],
@@ -710,6 +757,12 @@ void tMultiPackDlg::next_pressed()
 	  doneinstallscript_edit->text(), 1024);
   strncpy(params->KIFOptions.LibraryDir2[actpackage],
 	  librarydir_edit->text(), 1024);
+  params->KIFOptions.VersionMaj2[actpackage] =
+    atoi(versionmaj_edit->text());
+  params->KIFOptions.VersionMin2[actpackage] =
+    atoi(versionmin_edit->text());
+  params->KIFOptions.VersionRel2[actpackage] =
+    atoi(versionrel_edit->text());
 
   if(actpackage < MAX_ADDITIONAL_PACKAGES - 1)
     actpackage++;
@@ -729,10 +782,18 @@ void tMultiPackDlg::next_pressed()
   doneinstallscript_edit->
     setText(params->KIFOptions.DoneInstallScript2[actpackage]);
   librarydir_edit->setText(params->KIFOptions.LibraryDir2[actpackage]);
+  sprintf(cptr_version, "%i", params->KIFOptions.VersionMaj2[actpackage]);
+  versionmaj_edit->setText(cptr_version);
+  sprintf(cptr_version, "%i", params->KIFOptions.VersionMin2[actpackage]);
+  versionmin_edit->setText(cptr_version);
+  sprintf(cptr_version, "%i", params->KIFOptions.VersionRel2[actpackage]);
+  versionrel_edit->setText(cptr_version);
 }
 
 void tMultiPackDlg::back_pressed()
 {
+  char cptr_version[4];
+
   strncpy(params->KIFOptions.ProgramName2[actpackage],
 	  programname_edit->text(), 1024);
   strncpy(params->KIFOptions.CheckPriorFile2[actpackage],
@@ -753,6 +814,12 @@ void tMultiPackDlg::back_pressed()
 	  doneinstallscript_edit->text(), 1024);
   strncpy(params->KIFOptions.LibraryDir2[actpackage],
 	  librarydir_edit->text(), 1024);
+  params->KIFOptions.VersionMaj2[actpackage] =
+    atoi(versionmaj_edit->text());
+  params->KIFOptions.VersionMin2[actpackage] =
+    atoi(versionmin_edit->text());
+  params->KIFOptions.VersionRel2[actpackage] =
+    atoi(versionrel_edit->text());
 
   if(actpackage > 0)
     actpackage--;
@@ -772,6 +839,12 @@ void tMultiPackDlg::back_pressed()
   doneinstallscript_edit->
     setText(params->KIFOptions.DoneInstallScript2[actpackage]);
   librarydir_edit->setText(params->KIFOptions.LibraryDir2[actpackage]);
+  sprintf(cptr_version, "%i", params->KIFOptions.VersionMaj2[actpackage]);
+  versionmaj_edit->setText(cptr_version);
+  sprintf(cptr_version, "%i", params->KIFOptions.VersionMin2[actpackage]);
+  versionmin_edit->setText(cptr_version);
+  sprintf(cptr_version, "%i", params->KIFOptions.VersionRel2[actpackage]);
+  versionrel_edit->setText(cptr_version);
 }
 
 void tMultiPackDlg::ok_pressed()
@@ -798,6 +871,12 @@ void tMultiPackDlg::ok_pressed()
 	  doneinstallscript_edit->text(), 1024);
   strncpy(params->KIFOptions.LibraryDir2[actpackage],
 	  librarydir_edit->text(), 1024);
+  params->KIFOptions.VersionMaj2[actpackage] =
+    atoi(versionmaj_edit->text());
+  params->KIFOptions.VersionMin2[actpackage] =
+    atoi(versionmin_edit->text());
+  params->KIFOptions.VersionRel2[actpackage] =
+    atoi(versionrel_edit->text());
 
   for(i = 0;i < MAX_ADDITIONAL_PACKAGES;i++)
     {
@@ -821,6 +900,12 @@ void tMultiPackDlg::ok_pressed()
 	     params->KIFOptions.DoneInstallScript2[i]);
       strcpy(origparams->KIFOptions.LibraryDir2[i],
 	     params->KIFOptions.LibraryDir2[i]);
+      origparams->KIFOptions.VersionMaj2[i] =
+	params->KIFOptions.VersionMaj2[i];
+      origparams->KIFOptions.VersionMin2[i] =
+	params->KIFOptions.VersionMin2[i];
+      origparams->KIFOptions.VersionRel2[i] =
+	params->KIFOptions.VersionRel2[i];
     }
 
   hide();
@@ -839,6 +924,7 @@ void tMultiPackDlg::help_pressed()
 void tMultiPackDlg::showdlg(tParams* given_params)
 {
   int i;
+  char cptr_version[4];
 
   actpackage = 0;
   actpackage_lcd->display(actpackage + 1);
@@ -865,6 +951,12 @@ void tMultiPackDlg::showdlg(tParams* given_params)
 	     given_params->KIFOptions.DoneInstallScript2[i]);
       strcpy(params->KIFOptions.LibraryDir2[i],
 	     given_params->KIFOptions.LibraryDir2[i]);
+      params->KIFOptions.VersionMaj2[i] =
+	given_params->KIFOptions.VersionMaj2[i];
+      params->KIFOptions.VersionMin2[i] =
+	given_params->KIFOptions.VersionMin2[i];
+      params->KIFOptions.VersionRel2[i] =
+	given_params->KIFOptions.VersionRel2[i];
 
       strcpy(origparams->KIFOptions.ProgramName2[i],
 	     given_params->KIFOptions.ProgramName2[i]);
@@ -886,6 +978,12 @@ void tMultiPackDlg::showdlg(tParams* given_params)
 	     given_params->KIFOptions.DoneInstallScript2[i]);
       strcpy(origparams->KIFOptions.LibraryDir2[i],
 	     given_params->KIFOptions.LibraryDir2[i]);
+      origparams->KIFOptions.VersionMaj2[i] =
+	given_params->KIFOptions.VersionMaj2[i];
+      origparams->KIFOptions.VersionMin2[i] =
+	given_params->KIFOptions.VersionMin2[i];
+      origparams->KIFOptions.VersionRel2[i] =
+	given_params->KIFOptions.VersionRel2[i];
     }
 
   programname_edit->setText(params->KIFOptions.ProgramName2[actpackage]);
@@ -901,6 +999,12 @@ void tMultiPackDlg::showdlg(tParams* given_params)
   doneinstallscript_edit->
     setText(params->KIFOptions.DoneInstallScript2[actpackage]);
   librarydir_edit->setText(params->KIFOptions.LibraryDir2[actpackage]);
+  sprintf(cptr_version, "%i", params->KIFOptions.VersionMaj2[actpackage]);
+  versionmaj_edit->setText(cptr_version);
+  sprintf(cptr_version, "%i", params->KIFOptions.VersionMin2[actpackage]);
+  versionmin_edit->setText(cptr_version);
+  sprintf(cptr_version, "%i", params->KIFOptions.VersionRel2[actpackage]);
+  versionrel_edit->setText(cptr_version);
 
   show();
 
@@ -926,6 +1030,12 @@ void tMultiPackDlg::showdlg(tParams* given_params)
 	     origparams->KIFOptions.DoneInstallScript2[i]);
       strcpy(given_params->KIFOptions.LibraryDir2[i],
 	     origparams->KIFOptions.LibraryDir2[i]);
+      given_params->KIFOptions.VersionMaj2[i] =
+	origparams->KIFOptions.VersionMaj2[i];
+      given_params->KIFOptions.VersionMin2[i] =
+	origparams->KIFOptions.VersionMin2[i];
+      given_params->KIFOptions.VersionRel2[i] =
+	origparams->KIFOptions.VersionRel2[i];
     }
 }
 
