@@ -18,19 +18,6 @@
  ************************************************************************/
 
 #include "scriptbuild.h"
-#include "stringfunc.h"
-#include "tparams.h"
-#include "locale.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <sys/types.h>
-#include <fcntl.h>
-#include <unistd.h>
-#include <qdialog.h>
-#include <qmessagebox.h>
-#include <drag.h>
 
 #ifndef MIN_WIDTH
 #define MIN_WIDTH 550
@@ -69,7 +56,7 @@ kcreateinstScriptBuild::kcreateinstScriptBuild(QWidget *parent,
   scriptfilename_edit = new QLineEdit(this);
   scriptfilename_edit->setText("");
   scriptfilename_edit->show();
-  connect(scriptfilename_edit, SIGNAL(textChanged(const char*)),
+  connect(scriptfilename_edit, SIGNAL(textChanged(const QString &)),
 	  SLOT(scriptfilename_changed()));
 
   // Create scriptfilename_button
@@ -209,7 +196,7 @@ kcreateinstScriptBuild::kcreateinstScriptBuild(QWidget *parent,
 
   // Create File Selection Dialog
   FileSelector = new KFileDialog(getenv("HOME"), "*", this, "FileSelector",
-                                 false, false);
+                                 false);
   FileSelector->hide();
 
   // Create TGZViewer
@@ -1215,19 +1202,24 @@ void kcreateinstScriptBuild::cancel_pressed()
 void kcreateinstScriptBuild::help_pressed()
 {
   if(docinst_radio->isChecked())
-    kapp->invokeHTMLHelp("kcreateinst/scriptbuild.html", "docs");
+    KApplication::kApplication()->
+      invokeHTMLHelp("kcreateinst/scriptbuild.html", "docs");
 
   if(localedirinst_radio->isChecked())
-    kapp->invokeHTMLHelp("kcreateinst/scriptbuild.html", "locale");
+    KApplication::kApplication()->
+      invokeHTMLHelp("kcreateinst/scriptbuild.html", "locale");
 
   if(datadirinst_radio->isChecked())
-    kapp->invokeHTMLHelp("kcreateinst/scriptbuild.html", "datadir");
+    KApplication::kApplication()->
+      invokeHTMLHelp("kcreateinst/scriptbuild.html", "datadir");
 
   if(MIMEinst_radio->isChecked())
-    kapp->invokeHTMLHelp("kcreateinst/scriptbuild.html", "MIME");
+    KApplication::kApplication()->
+      invokeHTMLHelp("kcreateinst/scriptbuild.html", "MIME");
 
   if(deletedir_radio->isChecked())
-    kapp->invokeHTMLHelp("kcreateinst/scriptbuild.html", "deletedir");
+    KApplication::kApplication()->
+      invokeHTMLHelp("kcreateinst/scriptbuild.html", "deletedir");
 }
 
 void kcreateinstScriptBuild::scriptfilename_changed()
